@@ -63,8 +63,8 @@ def view_decorator(function):
 
 def relevance_vaild_legal_decorator(func):
     def wrapper(request, *args, **kwargs):
-        if request.method != "GET" and request.method != "POST":
-            return JsonResponse({"detail": f'Method "{request.method}" not allowed.'}, status=405)
+        # if request.method != "GET" and request.method != "POST":
+        #     return JsonResponse({"detail": f'Method "{request.method}" not allowed.'}, status=405)
         group = request.GET.get("group")
         if group:
             results = Results()
