@@ -391,10 +391,10 @@ class BaseJoinView(APIView, Select):
 
     def post(self, request, obj, obj_serializer, obj_relevance: list = None, m_to_m_obj: list = None,
              mapping=None,
-             m_to_m_mapping=None):
+             m_to_m_mapping=None, data=None):
         results = Results()
-
-        data = request.data
+        if not data:
+            data = request.data
         if data.get('data'):
             data = data.get('data')
         serializer = obj_serializer(data=data)
@@ -420,6 +420,50 @@ class BaseJoinView(APIView, Select):
 
         return RESTResponse(results)
 
+    def delete(self, request, obj, obj_serializer, data=None, pk="id", **kwargs):
+        """
+        根据主键删除数据
+        :param request:
+        :param obj:
+        :param obj_serializer:
+        :param data:
+        :param need_results:
+        :param pk:
+        :return:
+        """
+        results = Results()
+        results.code = 200
+        if not data:
+            data = request.data
+        if data.get('data'):
+            data = data.get('data')
+        if request.GET.get("pk"):
+            pk = request.GET.get("pk")
+        value_pk = data.get(pk)
+        if not value_pk:
+            results.describe = "'pk' cannot be empty"
+            results.code = REQUEST_ERROR_CODE
+        else:
+            try:
+                if pk == "id":
+                    try:
+                        value_pk = int(value_pk)
+                    except:
+                        raise ValidationError("'pk' type error Should be <int>！！！")
+
+                instance = obj.objects.filter(id=value_pk).first()
+                if not instance:
+                    results.describe = pk + "=" + str(value_pk) + " does not exist"
+                    results.code = REQUEST_ERROR_CODE
+                else:
+                    instance.delete()
+                    results.describe = "deleted successfully！！！"
+                    results.status = SUCCESS
+            except Exception as e:
+                results.code, results.describe = get_error_status_code(e)
+
+        return RESTResponse(results)
+
     def extend_relevance_data(self, data, queryset, obj_mapping):
         if queryset:
             value = getattr(queryset, obj_mapping[0], None)
