@@ -7,8 +7,8 @@ from common.utility.args_parsing import BaseArgsParsing
 
 
 class ESClient(BaseArgsParsing):
-    LIST_KEYWORD = ['must', 'should']
-    RANGE = 'range'
+    LIST_KEYWORD = ["must", "should"]
+    RANGE = "range"
 
     def conn(self, host=None, port=None, username=None, password=None):
         if username and password:
@@ -37,14 +37,14 @@ class ESClient(BaseArgsParsing):
 
     def build_suffix_keyword_args(self, body, key, keyword, value):
         if keyword == self.GT or keyword == self.GTE or keyword == self.LT or keyword == self.LTE:
-            if 'query' in body.keys():
+            if "query" in body.keys():
                 pass
             else:
-                body['query'] = {
+                body["query"] = {
                     "range": {
                         key: {
                             "gt": "2021-07-26T10:00:00Z",
-                            'lt': "2021-07-26T10:02:00Z",
+                            "lt": "2021-07-26T10:02:00Z",
                         }
                     }
                 }
@@ -52,25 +52,25 @@ class ESClient(BaseArgsParsing):
     def build(self, body, keys, field, vaule):
         if body is None:
             body = {}
-        if '.' in keys:
-            itme = keys.split('.')
+        if "." in keys:
+            itme = keys.split(".")
             key = itme[0]
             if isinstance(body, dict):
                 if key in body.keys():
-                    body[key] = self.build(body[key], '.'.join(itme[1:]), field, vaule)
+                    body[key] = self.build(body[key], ".".join(itme[1:]), field, vaule)
                     return body
                 else:
                     child_body = [] if key in self.LIST_KEYWORD else {}
-                    body[key] = self.build(child_body, '.'.join(itme[1:]), field, vaule)
+                    body[key] = self.build(child_body, ".".join(itme[1:]), field, vaule)
                     return body
             else:
                 if key == self.RANGE:
                     for range_item in body:
                         if key in range_item.keys():
                             if itme[1] in range_item[key].keys():
-                                range_item[key][itme[1]] = self.build(range_item[key], '.'.join(itme[1:]), field, vaule)
+                                range_item[key][itme[1]] = self.build(range_item[key], ".".join(itme[1:]), field, vaule)
                                 return body
-                body.append({key: self.build({}, '.'.join(itme[1:]), field, vaule)})
+                body.append({key: self.build({}, ".".join(itme[1:]), field, vaule)})
                 return body
 
         else:
@@ -80,11 +80,7 @@ class ESClient(BaseArgsParsing):
                     body[key][field] = vaule
                     return body[key]
                 else:
-                    return {
-                        key: {
-                            field: vaule
-                        }
-                    }
+                    return {key: {field: vaule}}
             else:
                 body.append({key: {field: vaule}})
                 return body
@@ -97,15 +93,15 @@ class ESClient(BaseArgsParsing):
     def build2(self, body, keys, field, vaule):
         if body is None:
             body = {}
-        if '.' in keys:
-            itme = keys.split('.')
+        if "." in keys:
+            itme = keys.split(".")
             key = itme[0]
             if key in body.keys():
-                body[key] = self.build(body[key], '.'.join(itme[1:]), field, vaule)
+                body[key] = self.build(body[key], ".".join(itme[1:]), field, vaule)
                 return body
             else:
                 child_body = [] if key in self.LIST_KEYWORD else {}
-                body[key] = self.build(child_body, '.'.join(itme[1:]), field, vaule)
+                body[key] = self.build(child_body, ".".join(itme[1:]), field, vaule)
                 return body
 
         else:
@@ -115,11 +111,7 @@ class ESClient(BaseArgsParsing):
                     body[key][field] = vaule
                     return body[key]
                 else:
-                    return {
-                        key: {
-                            field: vaule
-                        }
-                    }
+                    return {key: {field: vaule}}
             else:
                 body.append({key: {field: vaule}})
                 return body
@@ -127,40 +119,36 @@ class ESClient(BaseArgsParsing):
     def sort_(self, key, value, body=None):
         if not body:
             body = {}
-        sort_data = {
-            key: {
-                'order': value
-            }
-        }
-        if 'sort' in body.keys():
-            body['sort'].append(sort_data)
+        sort_data = {key: {"order": value}}
+        if "sort" in body.keys():
+            body["sort"].append(sort_data)
         else:
-            body['sort'] = [sort_data]
+            body["sort"] = [sort_data]
         return body
 
     def and_(self, key, value, body=None):
 
         # body = self.build(body, 'query.bool.must.match_phrase', key, value)
-        body = self.build(body, 'query.bool.must.match_phrase', key, value)
+        body = self.build(body, "query.bool.must.match_phrase", key, value)
         return body
 
     def or_(self, key, value, body=None):
 
         # body = self.build(body, 'query.bool.should.match_phrase', key, value)
-        body = self.build(body, 'query.bool.should.match_phrase', key, value)
+        body = self.build(body, "query.bool.should.match_phrase", key, value)
         return body
 
     def range_(self, key, kw, value, body=None):
         # body = self.build(body, 'query.bool.must.range.' + key, kw, value)
-        body = self.build(body, 'query.bool.must.range.' + key, kw, value)
+        body = self.build(body, "query.bool.must.range." + key, kw, value)
         return body
 
     def not_(self, key, value, body=None):
-        body = self.build(body, 'query.bool.must_not.match_phrase', key, value)
+        body = self.build(body, "query.bool.must_not.match_phrase", key, value)
         return body
 
     def must_and_should(self, key, value, body=None):
-        body = self.build(body, 'query.bool.must.bool.should.match_phrase', key, value)
+        body = self.build(body, "query.bool.must.bool.should.match_phrase", key, value)
         return body
 
     def search(self, body, index, page=1, size=20):
@@ -177,15 +165,15 @@ class ESClient(BaseArgsParsing):
         page_type_results = PageTypeResults()
         results.data = page_type_results
         try:
-            for item in es_results['hits']['hits']:
+            for item in es_results["hits"]["hits"]:
                 try:
-                    _source = item['_source']
+                    _source = item["_source"]
                     page_type_results.result.append(_source)
                 except Exception as e:
                     logger.exception(e)
             page_type_results.page = page
             page_type_results.size = size
-            page_type_results.total = es_results['hits']['total']['value']
+            page_type_results.total = es_results["hits"]["total"]["value"]
             results.data_length = len(page_type_results.result)
         except Exception as e:
             logger.exception(e)
@@ -201,8 +189,13 @@ class ESClient(BaseArgsParsing):
         self.es.index(index, body=body, id=id)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     es_client = ESClient()
-    body = es_client.and_('series', 'P')
-    es = es_client.conn()
+    body = es_client.and_("series", "P")
+    es = es_client.conn(
+        host="config.esmeas.host",
+        port="config.esmeas.port",
+        username="config.esmeas.username",
+        password="config.esmeas.password"
+    )
     es.index()
